//
//  SCAdListener.h
//  SmartclipSDKiOS
//
//  Copyright © 2019 smartclip. All rights reserved.
//
#ifndef SCAdListener_h
#define SCAdListener_h

@class SCAdEvent;

/**
 * Protocol that the video player uses to inform
 * the listener about certain events.
 */
@protocol SCAdListener <NSObject>
@optional
/**
 * Called when the content video has finished
 */
- (void)contentVideoFinished;

/**
 * Called when the AVPlayer actually starts video playback
 */
- (void)videoStartsPlayback;
@required
/**
 * Called when the content video fails for any reason
 */
- (void)contentVideoError:(NSError* _Nonnull )error;

/**
 * Called on for every ScAdInfo type change
 * - Parameter adInfo: current ScAdInfo
 */
- (void)onEventCallbackWithEvent:(SCAdEvent *_Nonnull )event;

/// Click through happened, pass it on to the view controller
- (void)displayClickThroughAlert:(UIAlertController* _Nonnull )alert;

/// Visibility of the adView changed, so pause or resume the player
- (void)visibilityChanged:(BOOL)visible;

/// The player detected a change of the presentationSize of the current AVPlayerItem
- (void)presentationSizeChangedTo:(CGSize)newSize;

- (nullable SCElementSize*)getPlayerSize;

- (nullable SCElementSize*)getViewportSize;
@end

#endif /* SCAdListener_h */
